import type { ISerializedResolveContext } from '@rushstack/webpack-workspace-resolve-plugin';
import type { IDependencyEntry, IResolverContext } from './types';
export declare function createBase32Hash(input: string): string;
export declare function depPathToFilename(depPath: string): string;
/**
 * Computes the root folder for a dependency from a reference to it in another package
 * @param lockfileFolder - The folder that contains the lockfile
 * @param key - The key of the dependency
 * @param specifier - The specifier in the lockfile for the dependency
 * @param context - The owning package
 * @returns The identifier for the dependency
 */
export declare function resolveDependencyKey(lockfileFolder: string, key: string, specifier: string, context: IResolverContext): string;
/**
 * Computes the physical path to a dependency based on its entry
 * @param lockfileFolder - The folder that contains the lockfile during installation
 * @param key - The key of the dependency
 * @param name - The name of the dependency, if provided
 * @returns The physical path to the dependency
 */
export declare function getDescriptionFileRootFromKey(lockfileFolder: string, key: string, name?: string): string;
export declare function resolveDependencies(lockfileFolder: string, collection: Record<string, IDependencyEntry>, context: IResolverContext): void;
/**
 *
 * @param depPath - The path to the dependency
 * @returns The folder name for the dependency
 */
export declare function depPathToFilenameUnescaped(depPath: string): string;
/**
 *
 * @param missingOptionalDependencies - The set of optional dependencies that were not installed
 * @param contexts - The map of context roots to their respective contexts
 * @param commonPathPrefix - The common root path to trim
 * @returns A function that serializes a context into a format that can be written to disk
 */
export declare function createContextSerializer(missingOptionalDependencies: Set<string>, contexts: Map<string, IResolverContext>, commonPathPrefix: string): (entry: [string, IResolverContext]) => ISerializedResolveContext;
//# sourceMappingURL=helpers.d.ts.map